pub enum CompressionAlgorithm {
GZIP,
}Expand description
If the feed document contents have been compressed, the compression algorithm used is returned in this property and you must decompress the feed when you download. Otherwise, you can download the feed directly. Refer to Step 6. Download and decrypt the feed processing report in the use case guide, where sample code is provided.
Variants
GZIP