Struct amazon_sp_feeds::models::feed_document::FeedDocument
source · [−]pub struct FeedDocument {
pub feed_document_id: String,
pub url: String,
pub encryption_details: Box<FeedDocumentEncryptionDetails>,
pub compression_algorithm: Option<CompressionAlgorithm>,
}Fields
feed_document_id: StringThe identifier for the feed document. This identifier is unique only in combination with a seller ID.
url: StringA presigned URL for the feed document. If compressionAlgorithm is not returned, you can download the feed directly from this URL. This URL expires after 5 minutes.
encryption_details: Box<FeedDocumentEncryptionDetails>compression_algorithm: Option<CompressionAlgorithm>If the feed document contents have been compressed, the compression algorithm used is returned in this property and you must decompress the feed when you download. Otherwise, you can download the feed directly. Refer to Step 6. Download and decrypt the feed processing report in the use case guide, where sample code is provided.
Implementations
sourceimpl FeedDocument
impl FeedDocument
pub fn new(
feed_document_id: String,
url: String,
encryption_details: FeedDocumentEncryptionDetails
) -> FeedDocument